==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Archiviazione non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "Unable to set upload directory." : "Impossibile impostare una cartella di caricamento.",
    "Invalid Token" : "Token non valido",
    "No file was uploaded. Unknown error" : "Nessun file è stato caricato. Errore sconosciuto",
    "There is no error, the file uploaded with success" : "Non ci sono errori, il file è stato caricato correttamente",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Il file caricato supera la direttiva upload_max_filesize in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The uploaded file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "No file was uploaded" : "Nessun file è stato caricato",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Failed to write to disk" : "Scrittura su disco non riuscita",
    "Not enough storage available" : "Spazio di archiviazione insufficiente",
    "The target folder has been moved or deleted." : "La cartella di destinazione è stata spostata o eliminata.",
    "Upload failed. Could not find uploaded file" : "Caricamento non riuscito. Impossibile trovare il file caricato.",
    "Upload failed. Could not get file info." : "Caricamento non riuscito. Impossibile ottenere informazioni sul file.",
    "Invalid directory." : "Cartella non valida.",
    "Files" : "File",
    "All files" : "Tutti i file",
    "Favorites" : "Preferiti",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Upload cancelled." : "Caricamento annullato.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte.",
    "Total file size {size1} exceeds upload limit {size2}" : "La dimensione totale del file {size1} supera il limite di caricamento {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Errore durante il caricamento del file \"{fileName}\": {message}",
    "Could not get result from server." : "Impossibile ottenere il risultato dal server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Caricamento del file in corso. La chiusura della pagina annullerà il caricamento.",
    "Actions" : "Azioni",
    "Download" : "Scarica",
    "Rename" : "Rinomina",
    "Delete" : "Elimina",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "Nessuna voce in questa cartella corrisponde a '{filter}'",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi di caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "Folder" : "Cartella",
    "New folder" : "Nuova cartella",
    "{newname} already exists" : "{newname} esiste già",
    "Upload" : "Carica",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "You created %1$s" : "Hai creato %1$s",
    "%2$s created %1$s" : "%2$s ha creato %1$s",
    "%1$s was created in a public folder" : "%1$s è stato creato in una cartella pubblica",
    "You changed %1$s" : "Hai modificato %1$s",
    "%2$s changed %1$s" : "%2$s ha modificato %1$s",
    "You deleted %1$s" : "Hai eliminato %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminato %1$s",
    "You restored %1$s" : "Hai ripristinato %1$s",
    "%2$s restored %1$s" : "%2$s ha ripristinato %1$s",
    "Changed by %2$s" : "Modificata da %2$s",
    "Deleted by %2$s" : "Eliminata da %2$s",
    "Restored by %2$s" : "Ripristinata da %2$s",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "Settings" : "Impostazioni",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\">accedere ai tuoi file con WebDAV</a>",
    "Cancel upload" : "Annulla caricamento",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites" : "Nessun preferito",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Changed by %2$s" : "Modificata da %2$s",
    "Deleted by %2$s" : "Eliminata da %2$s",
    "Restored by %2$s" : "Ripristinata da %2$s",
    "You changed %1$s" : "Hai modificato %1$s",
    "You created %1$s" : "Hai creato %1$s",
    "You deleted %1$s" : "Hai eliminato %1$s",
    "You restored %1$s" : "Hai ripristinato %1$s"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione non è temporaneamente disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "All files" : "Tutti i file",
    "Saved" : "Salvato",
    "There was an error saving" : "Si è verificato un errore durante il salvataggio",
    "File could not be found" : "Il file non può essere trovato",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Favorites" : "Preferiti",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "Upload cancelled." : "Caricamento annullato.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "Uploading..." : "Caricamento in corso...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Caricamento del file in corso. La chiusura della pagina annullerà il caricamento.",
    "Actions" : "Azioni",
    "Download" : "Scarica",
    "Rename" : "Rinomina",
    "Delete" : "Elimina",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "Invalid path" : "Percorso non valido",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["Incluso %n nascosto","Inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi di caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Collegamento Privato: Solo le persone che hanno accesso a questo file/cartella possono utilizzarlo.\nUtilizzalo come un collegamento permanente per te. Oppure, dentro una condivisione, per puntare a quei file.",
    "Folder" : "Cartella",
    "New folder" : "Nuova cartella",
    "{newname} already exists" : "{newname} esiste già",
    "Upload" : "Carica",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "You created %1$s" : "Hai creato %1$s",
    "%2$s created %1$s" : "%2$s ha creato %1$s",
    "%1$s was created in a public folder" : "%1$s è stato creato in una cartella pubblica",
    "You changed %1$s" : "Hai modificato %1$s",
    "%2$s changed %1$s" : "%2$s ha modificato %1$s",
    "You deleted %1$s" : "Hai eliminato %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminato %1$s",
    "You restored %1$s" : "Hai ripristinato %1$s",
    "%2$s restored %1$s" : "%2$s ha ripristinato %1$s",
    "Changed by %2$s" : "Modificata da %2$s",
    "Deleted by %2$s" : "Eliminata da %2$s",
    "Restored by %2$s" : "Ripristinata da %2$s",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedere ai tuoi file con WebDAV</a>",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites" : "Nessun preferito",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt"
},
"nplurals=2; plural=(n != 1);");
